Configuration
=============

Configuration loading and data classes.

.. module:: PASS.config

config
------

Configuration data classes.

.. automodule:: PASS.config.config
   :members:
   :undoc-members:
   :show-inheritance:

PassConfig
^^^^^^^^^^

.. autoclass:: PASS.config.config.PassConfig
   :members:
   :undoc-members:
   :show-inheritance:

Constants
^^^^^^^^^

.. autoclass:: PASS.config.config.Constants
   :members:
   :undoc-members:
   :show-inheritance:

Plots
^^^^^

.. autoclass:: PASS.config.config.Plots
   :members:
   :undoc-members:
   :show-inheritance:

load_config
-----------

Configuration file loading functions.

.. automodule:: PASS.config.load_config
   :members:
   :undoc-members:
   :show-inheritance:
